@@ -1,5 +1,6 @@
+from functools import lru_cache
 from importlib import import_module
-from typing import Dict, Any, Union, Type, List, Optional, Tuple
+from typing import Dict, Any, Union, List, Optional, Tuple
 
 import attr
 from attr.exceptions import NotAnAttrsClassError
@@ -40,37 +41,39 @@ except ImportError:
         )
 
 
-generic_types = [GenericType]
+generic_types = (GenericType,)
 
 try:
     # Python >= 3.9
     from types import GenericAlias
 
-    generic_types.append(GenericAlias)
+    generic_types += (GenericAlias,)
 except ImportError:
     pass
 
 
 NoneType = type(None)
 SUPPORTED_PRIMITIVES = {bool, int, float, str}
+_SUPPORTED_PRIMITIVES = tuple(SUPPORTED_PRIMITIVES)
 
 
 @attr.attrs
 class Field:
     name: str = attr.attrib()
-    field_type: Type = attr.attrib()
+    field_type: type = attr.attrib()
     mandatory: bool = attr.attrib()
     validator: Optional[callable] = attr.attrib(default=None)
     converter: Optional[callable] = attr.attrib(default=None)
 
 
 def resolve_types(
-    to_resolve: Dict[Union[Type, str], Any], globals: Dict[str, Any]
-) -> Dict[Type, Any]:
+    to_resolve: Dict[Union[type, str], Any], globals: Dict[str, Any]
+) -> Dict[type, Any]:
     return {_resolve_type(globals, k): v for k, v in to_resolve.items()}
 
 
-def get_fields(obj_type: Type) -> List[Field]:
+@lru_cache(None)
+def get_fields(obj_type: type) -> List[Field]:
     try:
         return [
             Field(f.name, f.type, f.default == attr.NOTHING, f.validator, f.converter)
@@ -91,12 +94,13 @@ def normalize_method(method) -> callable:
     return method.__func__ if isinstance(method, staticmethod) else method
 
 
+@lru_cache(None)
 def normalize_type(t: Union[type, GenericType]) -> Tuple[type, tuple]:
     if t == Any:
         t = None
     if _is_optional(t):
         return normalize_type(next(a for a in t.__args__ if a is not NoneType))
-    if any(isinstance(t, gt) for gt in generic_types):
+    if isinstance(t, generic_types):
         real_type = _get_origin(t)
         generic_args = t.__args__
     elif t is None or isinstance(t, type):
@@ -110,9 +114,10 @@ def normalize_type(t: Union[type, GenericType]) -> Tuple[type, tuple]:
 
 
 def is_obj_supported_primitive(obj):
-    return any(isinstance(obj, t) for t in SUPPORTED_PRIMITIVES) or obj is None
+    return isinstance(obj, _SUPPORTED_PRIMITIVES) or obj is None
 
 
+@lru_cache(None)
 def type_to_string(t: type, fully_qualified: bool) -> str:
     name = t.__name__
     if fully_qualified:
@@ -121,6 +126,7 @@ def type_to_string(t: type, fully_qualified: bool) -> str:
         return name
 
 
+@lru_cache(None)
 def fully_qualified_string_to_type(fully_qualified_type_name: str) -> type:
     module_name = fully_qualified_type_name[: fully_qualified_type_name.rindex(".")]
     class_name = fully_qualified_type_name[len(module_name) + 1 :]
